==> zio-aws-apigatewayv2_2.12-5.17.103.1-sources.jar: zio/aws/apigatewayv2/model/UpdateRouteRequest.scala <==
package zio.aws.apigatewayv2.model
import zio.ZIO
import zio.aws.apigatewayv2.model.primitives.{
  __string,
  __boolean,
  SelectionKey,
  StringWithLengthBetween1And64,
  SelectionExpression,
  StringWithLengthBetween1And128,
  Id
}
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class UpdateRouteRequest(
    apiId: __string,
    apiKeyRequired: Option[__boolean] = None,
    authorizationScopes: Option[Iterable[StringWithLengthBetween1And64]] = None,
    authorizationType: Option[zio.aws.apigatewayv2.model.AuthorizationType] =
      None,
    authorizerId: Option[Id] = None,
    modelSelectionExpression: Option[SelectionExpression] = None,
    operationName: Option[StringWithLengthBetween1And64] = None,
    requestModels: Option[Map[__string, StringWithLengthBetween1And128]] = None,
    requestParameters: Option[
      Map[__string, zio.aws.apigatewayv2.model.ParameterConstraints]
    ] = None,
    routeId: __string,
    routeKey: Option[SelectionKey] = None,
    routeResponseSelectionExpression: Option[SelectionExpression] = None,
    target: Option[StringWithLengthBetween1And128] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.apigatewayv2.model.UpdateRouteRequest = {
    import UpdateRouteRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.apigatewayv2.model.UpdateRouteRequest
      .builder()
      .apiId(__string.unwrap(apiId): java.lang.String)
      .optionallyWith(
        apiKeyRequired.map(value => __boolean.unwrap(value): java.lang.Boolean)
      )(_.apiKeyRequired)
      .optionallyWith(
        authorizationScopes.map(value =>
          value.map { item =>
            StringWithLengthBetween1And64.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.authorizationScopes)
      .optionallyWith(authorizationType.map(value => value.unwrap))(
        _.authorizationType
      )
      .optionallyWith(
        authorizerId.map(value => Id.unwrap(value): java.lang.String)
      )(_.authorizerId)
      .optionallyWith(
        modelSelectionExpression.map(value =>
          SelectionExpression.unwrap(value): java.lang.String
        )
      )(_.modelSelectionExpression)
      .optionallyWith(
        operationName.map(value =>
          StringWithLengthBetween1And64.unwrap(value): java.lang.String
        )
      )(_.operationName)
      .optionallyWith(
        requestModels.map(value =>
          value
            .map({ case (key, value) =>
              (__string.unwrap(
                key
              ): java.lang.String) -> (StringWithLengthBetween1And128.unwrap(
                value
              ): java.lang.String)
            })
            .asJava
        )
      )(_.requestModels)
      .optionallyWith(
        requestParameters.map(value =>
          value
            .map({ case (key, value) =>
              (__string.unwrap(key): java.lang.String) -> value.buildAwsValue()
            })
            .asJava
        )
      )(_.requestParameters)
      .routeId(__string.unwrap(routeId): java.lang.String)
      .optionallyWith(
        routeKey.map(value => SelectionKey.unwrap(value): java.lang.String)
      )(_.routeKey)
      .optionallyWith(
        routeResponseSelectionExpression.map(value =>
          SelectionExpression.unwrap(value): java.lang.String
        )
      )(_.routeResponseSelectionExpression)
      .optionallyWith(
        target.map(value =>
          StringWithLengthBetween1And128.unwrap(value): java.lang.String
        )
      )(_.target)
      .build()
  }
  def asReadOnly: zio.aws.apigatewayv2.model.UpdateRouteRequest.ReadOnly =
    zio.aws.apigatewayv2.model.UpdateRouteRequest.wrap(buildAwsValue())
}
object UpdateRouteRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.apigatewayv2.model.UpdateRouteRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.apigatewayv2.model.UpdateRouteRequest =
      zio.aws.apigatewayv2.model.UpdateRouteRequest(
        apiId,
        apiKeyRequired.map(value => value),
        authorizationScopes.map(value => value),
        authorizationType.map(value => value),
        authorizerId.map(value => value),
        modelSelectionExpression.map(value => value),
        operationName.map(value => value),
        requestModels.map(value => value),
        requestParameters.map(value =>
          value.map({ case (key, value) =>
            key -> value.asEditable
          })
        ),
        routeId,
        routeKey.map(value => value),
        routeResponseSelectionExpression.map(value => value),
        target.map(value => value)
      )
    def apiId: __string
    def apiKeyRequired: Option[__boolean]
    def authorizationScopes: Option[List[StringWithLengthBetween1And64]]
    def authorizationType: Option[zio.aws.apigatewayv2.model.AuthorizationType]
    def authorizerId: Option[Id]
    def modelSelectionExpression: Option[SelectionExpression]
    def operationName: Option[StringWithLengthBetween1And64]
    def requestModels: Option[Map[__string, StringWithLengthBetween1And128]]
    def requestParameters: Option[
      Map[__string, zio.aws.apigatewayv2.model.ParameterConstraints.ReadOnly]
    ]
    def routeId: __string
    def routeKey: Option[SelectionKey]
    def routeResponseSelectionExpression: Option[SelectionExpression]
    def target: Option[StringWithLengthBetween1And128]
    def getApiId: ZIO[Any, Nothing, __string] = ZIO.succeed(apiId)
    def getApiKeyRequired: ZIO[Any, AwsError, __boolean] =
      AwsError.unwrapOptionField("apiKeyRequired", apiKeyRequired)
    def getAuthorizationScopes
        : ZIO[Any, AwsError, List[StringWithLengthBetween1And64]] =
      AwsError.unwrapOptionField("authorizationScopes", authorizationScopes)
    def getAuthorizationType
        : ZIO[Any, AwsError, zio.aws.apigatewayv2.model.AuthorizationType] =
      AwsError.unwrapOptionField("authorizationType", authorizationType)
    def getAuthorizerId: ZIO[Any, AwsError, Id] =
      AwsError.unwrapOptionField("authorizerId", authorizerId)
    def getModelSelectionExpression: ZIO[Any, AwsError, SelectionExpression] =
      AwsError.unwrapOptionField(
        "modelSelectionExpression",
        modelSelectionExpression
      )
    def getOperationName: ZIO[Any, AwsError, StringWithLengthBetween1And64] =
      AwsError.unwrapOptionField("operationName", operationName)
    def getRequestModels
        : ZIO[Any, AwsError, Map[__string, StringWithLengthBetween1And128]] =
      AwsError.unwrapOptionField("requestModels", requestModels)
    def getRequestParameters: ZIO[Any, AwsError, Map[
      __string,
      zio.aws.apigatewayv2.model.ParameterConstraints.ReadOnly
    ]] = AwsError.unwrapOptionField("requestParameters", requestParameters)
    def getRouteId: ZIO[Any, Nothing, __string] = ZIO.succeed(routeId)
    def getRouteKey: ZIO[Any, AwsError, SelectionKey] =
      AwsError.unwrapOptionField("routeKey", routeKey)
    def getRouteResponseSelectionExpression
        : ZIO[Any, AwsError, SelectionExpression] = AwsError.unwrapOptionField(
      "routeResponseSelectionExpression",
      routeResponseSelectionExpression
    )
    def getTarget: ZIO[Any, AwsError, StringWithLengthBetween1And128] =
      AwsError.unwrapOptionField("target", target)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.apigatewayv2.model.UpdateRouteRequest
  ) extends zio.aws.apigatewayv2.model.UpdateRouteRequest.ReadOnly {
    override val apiId: __string =
      zio.aws.apigatewayv2.model.primitives.__string(impl.apiId())
    override val apiKeyRequired: Option[__boolean] = scala
      .Option(impl.apiKeyRequired())
      .map(value => zio.aws.apigatewayv2.model.primitives.__boolean(value))
    override val authorizationScopes
        : Option[List[StringWithLengthBetween1And64]] = scala
      .Option(impl.authorizationScopes())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.apigatewayv2.model.primitives
            .StringWithLengthBetween1And64(item)
        }.toList
      )
    override val authorizationType
        : Option[zio.aws.apigatewayv2.model.AuthorizationType] = scala
      .Option(impl.authorizationType())
      .map(value => zio.aws.apigatewayv2.model.AuthorizationType.wrap(value))
    override val authorizerId: Option[Id] = scala
      .Option(impl.authorizerId())
      .map(value => zio.aws.apigatewayv2.model.primitives.Id(value))
    override val modelSelectionExpression: Option[SelectionExpression] = scala
      .Option(impl.modelSelectionExpression())
      .map(value =>
        zio.aws.apigatewayv2.model.primitives.SelectionExpression(value)
      )
    override val operationName: Option[StringWithLengthBetween1And64] = scala
      .Option(impl.operationName())
      .map(value =>
        zio.aws.apigatewayv2.model.primitives
          .StringWithLengthBetween1And64(value)
      )
    override val requestModels
        : Option[Map[__string, StringWithLengthBetween1And128]] = scala
      .Option(impl.requestModels())
      .map(value =>
        value.asScala
          .map({ case (key, value) =>
            zio.aws.apigatewayv2.model.primitives
              .__string(key) -> zio.aws.apigatewayv2.model.primitives
              .StringWithLengthBetween1And128(value)
          })
          .toMap
      )
    override val requestParameters: Option[
      Map[__string, zio.aws.apigatewayv2.model.ParameterConstraints.ReadOnly]
    ] = scala
      .Option(impl.requestParameters())
      .map(value =>
        value.asScala
          .map({ case (key, value) =>
            zio.aws.apigatewayv2.model.primitives.__string(
              key
            ) -> zio.aws.apigatewayv2.model.ParameterConstraints.wrap(value)
          })
          .toMap
      )
    override val routeId: __string =
      zio.aws.apigatewayv2.model.primitives.__string(impl.routeId())
    override val routeKey: Option[SelectionKey] = scala
      .Option(impl.routeKey())
      .map(value => zio.aws.apigatewayv2.model.primitives.SelectionKey(value))
    override val routeResponseSelectionExpression: Option[SelectionExpression] =
      scala
        .Option(impl.routeResponseSelectionExpression())
        .map(value =>
          zio.aws.apigatewayv2.model.primitives.SelectionExpression(value)
        )
    override val target: Option[StringWithLengthBetween1And128] = scala
      .Option(impl.target())
      .map(value =>
        zio.aws.apigatewayv2.model.primitives
          .StringWithLengthBetween1And128(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.apigatewayv2.model.UpdateRouteRequest
  ): zio.aws.apigatewayv2.model.UpdateRouteRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-apigatewayv2_2.12-5.17.147.1-sources.jar: zio/aws/apigatewayv2/model/UpdateRouteRequest.scala <==
package zio.aws.apigatewayv2.model
import zio.ZIO
import zio.aws.apigatewayv2.model.primitives.{
  __string,
  __boolean,
  SelectionKey,
  StringWithLengthBetween1And64,
  SelectionExpression,
  StringWithLengthBetween1And128,
  Id
}
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class UpdateRouteRequest(
    apiId: __string,
    apiKeyRequired: Option[__boolean] = None,
    authorizationScopes: Option[Iterable[StringWithLengthBetween1And64]] = None,
    authorizationType: Option[zio.aws.apigatewayv2.model.AuthorizationType] =
      None,
    authorizerId: Option[Id] = None,
    modelSelectionExpression: Option[SelectionExpression] = None,
    operationName: Option[StringWithLengthBetween1And64] = None,
    requestModels: Option[Map[__string, StringWithLengthBetween1And128]] = None,
    requestParameters: Option[
      Map[__string, zio.aws.apigatewayv2.model.ParameterConstraints]
    ] = None,
    routeId: __string,
    routeKey: Option[SelectionKey] = None,
    routeResponseSelectionExpression: Option[SelectionExpression] = None,
    target: Option[StringWithLengthBetween1And128] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.apigatewayv2.model.UpdateRouteRequest = {
    import UpdateRouteRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.apigatewayv2.model.UpdateRouteRequest
      .builder()
      .apiId(apiId: java.lang.String)
      .optionallyWith(apiKeyRequired.map(value => value: java.lang.Boolean))(
        _.apiKeyRequired
      )
      .optionallyWith(
        authorizationScopes.map(value =>
          value.map { item =>
            StringWithLengthBetween1And64.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.authorizationScopes)
      .optionallyWith(authorizationType.map(value => value.unwrap))(
        _.authorizationType
      )
      .optionallyWith(
        authorizerId.map(value => Id.unwrap(value): java.lang.String)
      )(_.authorizerId)
      .optionallyWith(
        modelSelectionExpression.map(value =>
          SelectionExpression.unwrap(value): java.lang.String
        )
      )(_.modelSelectionExpression)
      .optionallyWith(
        operationName.map(value =>
          StringWithLengthBetween1And64.unwrap(value): java.lang.String
        )
      )(_.operationName)
      .optionallyWith(
        requestModels.map(value =>
          value
            .map({ case (key, value) =>
              (key: java.lang.String) -> (StringWithLengthBetween1And128.unwrap(
                value
              ): java.lang.String)
            })
            .asJava
        )
      )(_.requestModels)
      .optionallyWith(
        requestParameters.map(value =>
          value
            .map({ case (key, value) =>
              (key: java.lang.String) -> value.buildAwsValue()
            })
            .asJava
        )
      )(_.requestParameters)
      .routeId(routeId: java.lang.String)
      .optionallyWith(
        routeKey.map(value => SelectionKey.unwrap(value): java.lang.String)
      )(_.routeKey)
      .optionallyWith(
        routeResponseSelectionExpression.map(value =>
          SelectionExpression.unwrap(value): java.lang.String
        )
      )(_.routeResponseSelectionExpression)
      .optionallyWith(
        target.map(value =>
          StringWithLengthBetween1And128.unwrap(value): java.lang.String
        )
      )(_.target)
      .build()
  }
  def asReadOnly: zio.aws.apigatewayv2.model.UpdateRouteRequest.ReadOnly =
    zio.aws.apigatewayv2.model.UpdateRouteRequest.wrap(buildAwsValue())
}
object UpdateRouteRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.apigatewayv2.model.UpdateRouteRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.apigatewayv2.model.UpdateRouteRequest =
      zio.aws.apigatewayv2.model.UpdateRouteRequest(
        apiId,
        apiKeyRequired.map(value => value),
        authorizationScopes.map(value => value),
        authorizationType.map(value => value),
        authorizerId.map(value => value),
        modelSelectionExpression.map(value => value),
        operationName.map(value => value),
        requestModels.map(value => value),
        requestParameters.map(value =>
          value.map({ case (key, value) =>
            key -> value.asEditable
          })
        ),
        routeId,
        routeKey.map(value => value),
        routeResponseSelectionExpression.map(value => value),
        target.map(value => value)
      )
    def apiId: __string
    def apiKeyRequired: Option[__boolean]
    def authorizationScopes: Option[List[StringWithLengthBetween1And64]]
    def authorizationType: Option[zio.aws.apigatewayv2.model.AuthorizationType]
    def authorizerId: Option[Id]
    def modelSelectionExpression: Option[SelectionExpression]
    def operationName: Option[StringWithLengthBetween1And64]
    def requestModels: Option[Map[__string, StringWithLengthBetween1And128]]
    def requestParameters: Option[
      Map[__string, zio.aws.apigatewayv2.model.ParameterConstraints.ReadOnly]
    ]
    def routeId: __string
    def routeKey: Option[SelectionKey]
    def routeResponseSelectionExpression: Option[SelectionExpression]
    def target: Option[StringWithLengthBetween1And128]
    def getApiId: ZIO[Any, Nothing, __string] = ZIO.succeed(apiId)
    def getApiKeyRequired: ZIO[Any, AwsError, __boolean] =
      AwsError.unwrapOptionField("apiKeyRequired", apiKeyRequired)
    def getAuthorizationScopes
        : ZIO[Any, AwsError, List[StringWithLengthBetween1And64]] =
      AwsError.unwrapOptionField("authorizationScopes", authorizationScopes)
    def getAuthorizationType
        : ZIO[Any, AwsError, zio.aws.apigatewayv2.model.AuthorizationType] =
      AwsError.unwrapOptionField("authorizationType", authorizationType)
    def getAuthorizerId: ZIO[Any, AwsError, Id] =
      AwsError.unwrapOptionField("authorizerId", authorizerId)
    def getModelSelectionExpression: ZIO[Any, AwsError, SelectionExpression] =
      AwsError.unwrapOptionField(
        "modelSelectionExpression",
        modelSelectionExpression
      )
    def getOperationName: ZIO[Any, AwsError, StringWithLengthBetween1And64] =
      AwsError.unwrapOptionField("operationName", operationName)
    def getRequestModels
        : ZIO[Any, AwsError, Map[__string, StringWithLengthBetween1And128]] =
      AwsError.unwrapOptionField("requestModels", requestModels)
    def getRequestParameters: ZIO[Any, AwsError, Map[
      __string,
      zio.aws.apigatewayv2.model.ParameterConstraints.ReadOnly
    ]] = AwsError.unwrapOptionField("requestParameters", requestParameters)
    def getRouteId: ZIO[Any, Nothing, __string] = ZIO.succeed(routeId)
    def getRouteKey: ZIO[Any, AwsError, SelectionKey] =
      AwsError.unwrapOptionField("routeKey", routeKey)
    def getRouteResponseSelectionExpression
        : ZIO[Any, AwsError, SelectionExpression] = AwsError.unwrapOptionField(
      "routeResponseSelectionExpression",
      routeResponseSelectionExpression
    )
    def getTarget: ZIO[Any, AwsError, StringWithLengthBetween1And128] =
      AwsError.unwrapOptionField("target", target)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.apigatewayv2.model.UpdateRouteRequest
  ) extends zio.aws.apigatewayv2.model.UpdateRouteRequest.ReadOnly {
    override val apiId: __string = impl.apiId(): __string
    override val apiKeyRequired: Option[__boolean] =
      scala.Option(impl.apiKeyRequired()).map(value => value: __boolean)
    override val authorizationScopes
        : Option[List[StringWithLengthBetween1And64]] = scala
      .Option(impl.authorizationScopes())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.apigatewayv2.model.primitives
            .StringWithLengthBetween1And64(item)
        }.toList
      )
    override val authorizationType
        : Option[zio.aws.apigatewayv2.model.AuthorizationType] = scala
      .Option(impl.authorizationType())
      .map(value => zio.aws.apigatewayv2.model.AuthorizationType.wrap(value))
    override val authorizerId: Option[Id] = scala
      .Option(impl.authorizerId())
      .map(value => zio.aws.apigatewayv2.model.primitives.Id(value))
    override val modelSelectionExpression: Option[SelectionExpression] = scala
      .Option(impl.modelSelectionExpression())
      .map(value =>
        zio.aws.apigatewayv2.model.primitives.SelectionExpression(value)
      )
    override val operationName: Option[StringWithLengthBetween1And64] = scala
      .Option(impl.operationName())
      .map(value =>
        zio.aws.apigatewayv2.model.primitives
          .StringWithLengthBetween1And64(value)
      )
    override val requestModels
        : Option[Map[__string, StringWithLengthBetween1And128]] = scala
      .Option(impl.requestModels())
      .map(value =>
        value.asScala
          .map({ case (key, value) =>
            (key: __string) -> zio.aws.apigatewayv2.model.primitives
              .StringWithLengthBetween1And128(value)
          })
          .toMap
      )
    override val requestParameters: Option[
      Map[__string, zio.aws.apigatewayv2.model.ParameterConstraints.ReadOnly]
    ] = scala
      .Option(impl.requestParameters())
      .map(value =>
        value.asScala
          .map({ case (key, value) =>
            (key: __string) -> zio.aws.apigatewayv2.model.ParameterConstraints
              .wrap(value)
          })
          .toMap
      )
    override val routeId: __string = impl.routeId(): __string
    override val routeKey: Option[SelectionKey] = scala
      .Option(impl.routeKey())
      .map(value => zio.aws.apigatewayv2.model.primitives.SelectionKey(value))
    override val routeResponseSelectionExpression: Option[SelectionExpression] =
      scala
        .Option(impl.routeResponseSelectionExpression())
        .map(value =>
          zio.aws.apigatewayv2.model.primitives.SelectionExpression(value)
        )
    override val target: Option[StringWithLengthBetween1And128] = scala
      .Option(impl.target())
      .map(value =>
        zio.aws.apigatewayv2.model.primitives
          .StringWithLengthBetween1And128(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.apigatewayv2.model.UpdateRouteRequest
  ): zio.aws.apigatewayv2.model.UpdateRouteRequest.ReadOnly = new Wrapper(impl)
}
